# Microsoft Power Platform Management SDK

Integrate the Microsoft [Power Platform API](https://learn.microsoft.com/rest/api/power-platform/) into your project!

## Installation
To install the client library via pip install:

Search for powerplatform-management in the pypi.org, or
Type `pip install powerplatform-management`.

## Getting started
1. Register your application
Register your application to use Power Platform API using following the [Authentication](https://learn.microsoft.com/power-platform/admin/programmability-authentication-v2) instructions.

2. Follow a tutorial
We provide a number of tutorials today across various tools/SDKs.  Feel free to use one as an easy way to learn how to leverage the .NET SDK and automate to your heart's content!

* [Create a daily capacity report](https://learn.microsoft.com/en-us/power-platform/admin/programmability-tutorial-create-daily-capacity-report?tabs=Azure)
* [Install an application to a target environment](https://learn.microsoft.com/en-us/power-platform/admin/programmability-tutorial-install-application-environment?tabs=Azure)
* [Allocate add-ons to environments](https://learn.microsoft.com/en-us/power-platform/admin/programmability-tutorial-allocate-capacity-addons?tabs=PPAC)
* [Create cross tenant isolation reports](https://learn.microsoft.com/en-us/power-platform/admin/programmability-tutorial-cross-tenant-reporting?tabs=Automate)
* [Create, update, and list Environment Management Settings](https://learn.microsoft.com/en-us/power-platform/admin/programmability-tutorial-environmentmanagement-settings)
